RustCrypto: Ascon permutation
Pure Rust implementation of the Ascon permutation, winner of the NIST Lightweight Cryptography competition.
This is a low-level crate used for implementation of higher-level agorithms,
e.g. ascon-hash256, ascon-xof128, and ascon-aead128.
Minimum Supported Rust Version
This crate requires Rust 1.85 at a minimum.
We may change the MSRV in the future, but it will be accompanied by a minor version bump.
License
Licensed under either of:
at your option.
Contribution
Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.
Functions
- permute
- Apply Ascon permutation with the given number of rounds.
- permute6
- Apply Ascon permutation with 6 rounds.
- permute8
- Apply Ascon permutation with 8 rounds.
- permute12
- Apply Ascon permutation with 12 rounds.
Type Aliases
- State
- Ascon’s permutation state